# swagger_client.OrdersApi

All URIs are relative to *https://api.ingrammicro.com:443/sandbox/resellers/v5*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_orders_order_number**](OrdersApi.md#delete_orders_order_number) | **DELETE** /orders/{ordernumber} | Cancel an existing order
[**get_orders_search**](OrdersApi.md#get_orders_search) | **GET** /orders/search | Search Your Orders
[**get_v5_orders_details**](OrdersApi.md#get_v5_orders_details) | **GET** /orders/{ordernumber} | Get order details
[**post_v5_orders_create**](OrdersApi.md#post_v5_orders_create) | **POST** /orders | Create a new order

# **delete_orders_order_number**
> OrderCancelResponse delete_orders_order_number(ordernumber, customer_number, iso_country_code, entry_date)

Cancel an existing order

A request to cancel a previously accepted order, this call must be submitted before the order is released to Ingram Micro’s warehouse.    The order cannot be canceled once it is released to the warehouse.  *Direct ship orders cannot be canceled.  Contact your sales rep for assistance.  *NOTE: orderNumber, isoCountryCode, customerNumber and entryDate is mandatory.*

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: application
configuration = swagger_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = swagger_client.OrdersApi(swagger_client.ApiClient(configuration))
ordernumber = 'ordernumber_example' # str | Ingram Micro sales order number
customer_number = 'customer_number_example' # str | Your unique Ingram Micro customer number
iso_country_code = 'iso_country_code_example' # str | 2 chars ISO country code
entry_date = '2020-04-03' # str | Order entry date (yyyy-mm-dd) (default to 2020-04-03)

try:
    # Cancel an existing order
    api_response = api_instance.delete_orders_order_number(ordernumber, customer_number, iso_country_code, entry_date)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling OrdersApi->delete_orders_order_number: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ordernumber** | **str**| Ingram Micro sales order number | 
 **customer_number** | **str**| Your unique Ingram Micro customer number | 
 **iso_country_code** | **str**| 2 chars ISO country code | 
 **entry_date** | **str**| Order entry date (yyyy-mm-dd) | [default to 2020-04-03]

### Return type

[**OrderCancelResponse**](OrderCancelResponse.md)

### Authorization

[application](../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_orders_search**
> OrderSearchResponse get_orders_search(customer_number, isocountrycode, ordernumber=ordernumber, customerordernumber=customerordernumber, orderstatus=orderstatus, startcreatetimestamp=startcreatetimestamp, endcreatetimestamp=endcreatetimestamp, pagesize=pagesize, pagenumber=pagenumber)

Search Your Orders

Easy to use, and implement order search API endpoint with the capability to search using various parameters, supports pagination. Search using any or all of the parameters below- 1. ordernumber - Ingram Micro sales order number 2. customerordernumber - The PO or order number provided by you when creating an order 3. orderstatus - user order status codes for the search, default is set to \"any\" 4. startcreatetimestamp and endcreatetimestamp - Order create date range  For pagination please use following parameters -  1. pagesize - default 25, max 100 2. pagenumber - default 1  Search mechanism -  1. If no search or filter criteria provided then records are returnedin descending order of creation 2. If all the search parameters are provided then all of them are used for search  Order Status values -  P - PENDING                       R - RELEASED                      4 - SHIPPED                       I - INVOICED                    V - VOIDED                       The search endpoint also return HATEOAS links for order details and invoice details if applicable. 

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: application
configuration = swagger_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = swagger_client.OrdersApi(swagger_client.ApiClient(configuration))
customer_number = 'customer_number_example' # str | Your unique Ingram Micro customer number
isocountrycode = 'isocountrycode_example' # str | 2 char iso country code
ordernumber = 'ordernumber_example' # str | Ingram sales order number (optional)
customerordernumber = 'customerordernumber_example' # str | Search using your PO/Order number (optional)
orderstatus = 'any' # str | Ingram Micro order status (optional) (default to any)
startcreatetimestamp = '2013-10-20T19:20:30+01:00' # datetime | Search start date/time in UTC format (optional)
endcreatetimestamp = '2013-10-20T19:20:30+01:00' # datetime | Search end date/time in UTC format (optional)
pagesize = 56 # int | Number of records required in the call (optional)
pagenumber = 1 # int | the page number reference (optional) (default to 1)

try:
    # Search Your Orders
    api_response = api_instance.get_orders_search(customer_number, isocountrycode, ordernumber=ordernumber, customerordernumber=customerordernumber, orderstatus=orderstatus, startcreatetimestamp=startcreatetimestamp, endcreatetimestamp=endcreatetimestamp, pagesize=pagesize, pagenumber=pagenumber)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling OrdersApi->get_orders_search: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customer_number** | **str**| Your unique Ingram Micro customer number | 
 **isocountrycode** | **str**| 2 char iso country code | 
 **ordernumber** | **str**| Ingram sales order number | [optional] 
 **customerordernumber** | **str**| Search using your PO/Order number | [optional] 
 **orderstatus** | **str**| Ingram Micro order status | [optional] [default to any]
 **startcreatetimestamp** | **datetime**| Search start date/time in UTC format | [optional] 
 **endcreatetimestamp** | **datetime**| Search end date/time in UTC format | [optional] 
 **pagesize** | **int**| Number of records required in the call | [optional] 
 **pagenumber** | **int**| the page number reference | [optional] [default to 1]

### Return type

[**OrderSearchResponse**](OrderSearchResponse.md)

### Authorization

[application](../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_v5_orders_details**
> OrderDetailResponse get_v5_orders_details(ordernumber, customernumber, isocountrycode, customerordernumber=customerordernumber, startcreatetimestamp=startcreatetimestamp, endcreatetimestamp=endcreatetimestamp)

Get order details

Retrieve details of an existing order using Ingram Micro sales order number. The sales order number is returned in the order create POST response.   It is highly recommended that you store the IM sales order number. You can also retrieve the IM sales order number by searching your existing order using various parameters including customer PO/order number provided by you at the time of creating the order.  In case the IM sales order number is repeated, you can refine the result by providing customerordernumber for additional filtering and/or using the date range to filter on order creation date.   *NOTE: ordernumber, isocountrycode and customernumber is mandatory.*

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: application
configuration = swagger_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = swagger_client.OrdersApi(swagger_client.ApiClient(configuration))
ordernumber = 'ordernumber_example' # str | Ingram Micro sales order number
customernumber = '20-222222' # str | Your unique Ingram Micro customer number (default to 20-222222)
isocountrycode = 'US' # str | 2 chars ISO country code (default to US)
customerordernumber = 'customerordernumber_example' # str | Your PO/Order Number provide at the time of order creation (optional)
startcreatetimestamp = '2013-10-20' # date | Filter start date - format YYYY-MM-DD (optional)
endcreatetimestamp = 'endcreatetimestamp_example' # str | Filter end date - format YYYY-MM-DD (optional)

try:
    # Get order details
    api_response = api_instance.get_v5_orders_details(ordernumber, customernumber, isocountrycode, customerordernumber=customerordernumber, startcreatetimestamp=startcreatetimestamp, endcreatetimestamp=endcreatetimestamp)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling OrdersApi->get_v5_orders_details: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ordernumber** | **str**| Ingram Micro sales order number | 
 **customernumber** | **str**| Your unique Ingram Micro customer number | [default to 20-222222]
 **isocountrycode** | **str**| 2 chars ISO country code | [default to US]
 **customerordernumber** | **str**| Your PO/Order Number provide at the time of order creation | [optional] 
 **startcreatetimestamp** | **date**| Filter start date - format YYYY-MM-DD | [optional] 
 **endcreatetimestamp** | **str**| Filter end date - format YYYY-MM-DD | [optional] 

### Return type

[**OrderDetailResponse**](OrderDetailResponse.md)

### Authorization

[application](../README.md#application)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **post_v5_orders_create**
> OrderCreateResponse post_v5_orders_create(body=body)

Create a new order

Use POST order create API for instant ordering with Ingram Micro. The API supports stocked SKUs as well as licensing and warranties SKUs. It is highly recommended to provide \"ingrampartnumber\" for the SKUs.  For using vendorpartnumber to place the orders, please use the product search endpoint to find the ingrampartnumber for a specific vendorpartnumber and then supply the ingrampartnumber to place an order.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: application
configuration = swagger_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = swagger_client.OrdersApi(swagger_client.ApiClient(configuration))
body = swagger_client.OrderCreateRequest() # OrderCreateRequest |  (optional)

try:
    # Create a new order
    api_response = api_instance.post_v5_orders_create(body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling OrdersApi->post_v5_orders_create: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**OrderCreateRequest**](OrderCreateRequest.md)|  | [optional] 

### Return type

[**OrderCreateResponse**](OrderCreateResponse.md)

### Authorization

[application](../README.md#application)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

